@@ -3,13 +3,16 @@ static const char cright_years_z[] =
 
 /* uudecode utility.   Copyright (C) */
 
-   "1994, 1995, 1996, 2002, 2005, 2006";
+   "1994, 1995, 1996, 2002, 2005, 2006, 2007";
 
  /* Free Software Foundation, Inc.
 
+   Copyright (C) 1994, 1995, 1996, 2002, 2005, 2006,
+   2007 Free Software Foundation, Inc.
+
    This product is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This product is distributed in the hope that it will be useful,
