@@ -1,9 +1,14 @@
+
+static const char cright_years_z[] =
+   "1994, 1995, 1996, 2002, 2005, 2007";
+
 /* uuencode utility.
-   Copyright (C) 1994, 1995, 1996, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1994, 1995, 1996, 2002, 2005,
+   2007 Free Software Foundation, Inc.
 
    This product is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This product is distributed in the hope that it will be useful,
@@ -13,8 +18,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this product; see the file COPYING.  If not, write to
-   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.  */
+   the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* Copyright (c) 1983 Regents of the University of California.
    All rights reserved.
@@ -249,9 +254,8 @@ main (argc, argv)
 	  /* xgettext: no-wrap */
 	  printf (_("Copyright (C) %s Free Software Foundation, Inc.\n\
 This is free software; see the source for copying conditions.  There is NO\n\
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
-"),
-		  "1994, 1995, 1996, 2002");
+warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
+		  cright_years_z);
 	  exit (EXIT_SUCCESS);
 
 	case 0:
@@ -265,16 +269,24 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
   switch (argc - optind)
     {
     case 2:
-
       /* Optional first argument is input file.  */
-
-      if (!freopen (argv[optind], "r", stdin) || fstat (fileno (stdin), &sb))
-	error (EXIT_FAILURE, errno, "%s", argv[optind]);
-      mode = sb.st_mode & (S_IRWXU | S_IRWXG | S_IRWXO);
-      optind++;
-      break;
+      {
+	FILE *fp = freopen (argv[optind], FOPEN_READ_BINARY, stdin);
+	if (fp != stdin)
+	  error (EXIT_FAILURE, errno, _("fopen-ing %s"), argv[optind]);
+	if (fstat (fileno (stdin), &sb) != 0)
+	  error (EXIT_FAILURE, errno, _("fstat-ing %s"), argv[optind]);
+	mode = sb.st_mode & (S_IRWXU | S_IRWXG | S_IRWXO);
+	optind++;
+	break;
+      }
 
     case 1:
+#if __CYGWIN
+      if (! isatty (STDIN_FILENO))
+       setmode (STDIN_FILENO, O_BINARY);
+#endif
+
       mode = RW & ~umask (RW);
       break;
 
